@@ -26,7 +26,7 @@
 namespace QPulseAudio
 {
 
-class Q_DECL_EXPORT Source : public Device
+class Source : public Device
 {
     Q_OBJECT
 public:
@@ -36,6 +36,10 @@ public:
     void setVolume(qint64 volume) Q_DECL_OVERRIDE;
     void setMuted(bool muted) Q_DECL_OVERRIDE;
     void setActivePortIndex(quint32 port_index) Q_DECL_OVERRIDE;
+    void setChannelVolume(int channel, qint64 volume) Q_DECL_OVERRIDE;
+
+    bool isDefault() const Q_DECL_OVERRIDE;
+    void setDefault(bool enable) Q_DECL_OVERRIDE;
 };
 
 } // QPulseAudio
